#
# spec file for package uhttpmock
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uhttpmock
Version:        0.11.0
Release:        1.3
Summary:        HTTP web service mocking library
License:        LGPL-2.1-or-later
Group:          Development/Tools/Other
URL:            https://gitlab.freedesktop.org/pwithnall/uhttpmock
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.38.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(libsoup-3.0) >= 3.1.2
BuildRequires:  pkgconfig(vapigen)

%description
uhttpmock is a project for mocking web service APIs which use HTTP or HTTPS.
It provides a library, libuhttpmock, which implements recording and
playback of HTTP request/response traces.

%package -n libuhttpmock-1_0-1
Summary:        HTTP web service mocking library
Group:          System/Libraries

%description -n libuhttpmock-1_0-1
uhttpmock is a project for mocking web service APIs which use HTTP or HTTPS.
It provides a library, libuhttpmock, which implements recording and
playback of HTTP request/response traces.

%package -n typelib-1_0-Uhm-1_0
Summary:        HTTP web service mocking library
Group:          System/Libraries

%description -n typelib-1_0-Uhm-1_0
uhttpmock is a project for mocking web service APIs which use HTTP or HTTPS.
It provides a library, libuhttpmock, which implements recording and
playback of HTTP request/response traces.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Other
Requires:       libuhttpmock-1_0-1 = %{version}
Requires:       typelib-1_0-Uhm-1_0 = %{version}

%description devel
This package contains libraries, header files and documentation for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%meson \
	-Dgtk_doc=true \
	-Dintrospection=true \
	-Dvapi=enabled \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libuhttpmock-1_0-1

%files -n libuhttpmock-1_0-1
%license COPYING
%doc README NEWS AUTHORS
%{_libdir}/libuhttpmock-1.0.so.*

%files -n typelib-1_0-Uhm-1_0
%{_libdir}/girepository-1.0/Uhm-1.0.typelib

%files devel
%doc %{_datadir}/gtk-doc/html/libuhttpmock-1.0/
%{_libdir}/*.so
%{_includedir}/libuhttpmock-1.0/
%{_libdir}/pkgconfig/libuhttpmock-1.0.pc
%{_datadir}/gir-1.0/Uhm-1.0.gir
%{_datadir}/vala/vapi/

%changelog
* Wed Jun 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.11.0:
  + Dump hosts during record.
  + Add HTTP/2 support.
  + Add Location field support.
  + Fix memory leak in uhm_message_finalize.
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.10.0:
  + Bugs fixed:
  - Add PATCH request method.
  - Add CONNECT request method.
* Tue Oct 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.9.0:
  + This release ports the library to use libsoup 3.x. Note that
    you should stick to using the latest 0.5.x version if the
    tested piece of software still requires libsoup 2.x as the 2
    versions cannot be used in the same programm.
- Replace pkgconfig(libsoup-2.4) with pkgconfig(libsoup-3.0)
  BuildRequires following upstreams port.
- Rename sub-package typelib and shared library following upstreams
  bump of soname.
* Mon Sep  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.5.5:
  + This release fixes the gtk-doc directory containing the version
    number twice.
- Changes from version 0.5.4:
  + This new release drops support for autotools, by using the
    meson build system, and older versions of libsoup 2.x.
- Add gtk-doc and meson BuildRequires and macros.
- Use ldconfig_scriptlets for post(un) handling.
- Update URL and Source to new home.
* Thu Feb 25 2021 Wang Jun <jgwang@suse.com>
- Update to version 0.5.3
  * Add an integration tutorial (by Rasmus Thomsen) (#3)
  * Only specify SOUP_SERVER_LISTEN_HTTPS if TLS is enabled (!9)
  * Expand TLS certificate instructions (!10)
  * Add GitLab CI
  * Fix autoconf-archive usage due to them breaking API
  * Bump GObject dependency to 2.38 to use newer private data API
* Fri Dec 28 2018 bjorn.lie@gmail.com
- Update to version 0.5.1:
  + Fix header include path in GIR/VAPI file.
  + Various build system cleanups.
- Tweak Group to silence rpmlint.
- Add pkgconfig(vapigen) BuildRequires: Build vala support.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
* Sun Jul 12 2015 zaitor@opensuse.org
- Update to version 0.5.0:
  + Major changes: Minor documentation updates.
  + API changes:
  - Add uhm_server_filter_ignore_parameter_values().
  - Add uhm_server_compare_messages_remove_filter().
* Mon May  4 2015 zaitor@opensuse.org
- Update to version 0.4.0:
  + Fix comparison mode.
  + Add optional support for libsoup 2.47.3’s new SoupServer API.
  + Fix some memory leaks.
  + Fix parsing of certain trace files.
  + Various build system updates.
  + Move home page from gitorious to
    https://gitlab.com/groups/uhttpmock
  + Port from GAsyncResult to GTask, requiring a GIO dependency
    bump to 2.36.0.
  + Bugs fixed: bgo#748200.
* Thu Jan  1 2015 zaitor@opensuse.org
- Update to version 0.3.3:
  + Fix comparison mode.
- Changes from version 0.3.2:
  + Fix some memory leaks.
  + Rearchitect trace file parsing to correctly handle buffer
    boundaries.
- Changes from version 0.3.1:
  + Add optional support for libsoup ≥ 2.47.3.
- Changes from version 0.3.0:
  + Major changes:
  - Drop useless gthread dependency.
  - Thread safety fixes.
  + API changes:
  - Add uhm_server_set_expected_domain_names().
  - Add uhm_server_received_message_chunk_with_direction(),
    uhm_server_received_message_chunk_from_soup().
  + Bugs fixed:
  - rh#1026764: Review Request: uhttpmock - HTTP web service
    mocking library.
  - bgo#731040: libgdata-0.14.3 tests fail.
- Drop pkgconfig(gthread-2.0) BuildRequires following upstream.
- Add ldconfig calls to libuhttpmock-0_0-0 post and postun.
* Thu Dec 19 2013 dimstar@opensuse.org
- Initial package, version 0.2.0.
